@@ -1,9 +1,12 @@
 import logging
+import tempfile
+from typing import Optional, Any, AsyncGenerator
 
+import aiohttp
 from aiohttp import ClientResponseError, ClientError
 from lxml.etree import LxmlError
 from gettext import gettext as _
-from os import environ, path
+from os import environ
 
 from rest_framework import serializers
 
@@ -111,9 +114,10 @@ class PythonBanderStage(Stage):
         """
         If includes is specified, then only sync those,else try to sync all other packages
         """
-        # Prevent bandersnatch from reading actual .netrc file, set to nonexistent file
+        # Prevent bandersnatch from reading actual .netrc file, set to empty file
         # See discussion on https://github.com/pulp/pulp_python/issues/581
-        environ["NETRC"] = f"{path.curdir}/.fake-netrc"
+        fake_netrc = tempfile.NamedTemporaryFile(dir=".", delete=False)
+        environ["NETRC"] = fake_netrc.name
         # TODO Change Bandersnatch internal API to take proxy settings in from config parameters
         if proxy_url := self.remote.proxy_url:
             if self.remote.proxy_username or self.remote.proxy_password:
@@ -126,7 +130,7 @@ class PythonBanderStage(Stage):
         # Bandersnatch includes leading slash when forming API urls
         url = self.remote.url.rstrip("/")
         # local & global timeouts defaults to 10secs and 5 hours
-        async with Master(url) as master:
+        async with PulpMaster(url, tls=self.remote.tls_validation) as master:
             deferred_download = self.remote.policy != Remote.IMMEDIATE
             workers = self.remote.download_concurrency or self.remote.DEFAULT_DOWNLOAD_CONCURRENCY
             async with ProgressReport(
@@ -148,6 +152,25 @@ class PythonBanderStage(Stage):
                 await pmirror.synchronize(packages_to_sync)
 
 
+class PulpMaster(Master):
+    """
+    Pulp Master Class for Pulp specific overrides
+    """
+
+    def __init__(self, *args, tls=True, **kwargs):
+        self.tls = tls
+        super().__init__(*args, **kwargs)
+
+    async def get(
+        self, path: str, required_serial: Optional[int], **kw: Any
+    ) -> AsyncGenerator[aiohttp.ClientResponse, None]:
+        """Support tls=false"""
+        if not self.tls:
+            kw["ssl"] = False
+        async for r in super().get(path, required_serial, **kw):
+            yield r
+
+
 class PulpMirror(Mirror):
     """
     Pulp Mirror Class to perform syncing using Bandersnatch
@@ -257,4 +280,4 @@ class PulpMirror(Mirror):
         TODO
         This should have some error checking
         """
-        pass
+        logger.error("Sync encountered an error: ", exc_info=exception)
